==> v0.0.7.zip: antares/src/renderer/i18n/en-US.js <==
module.exports = {
   word: {
      edit: 'Edit',
      save: 'Save',
      close: 'Close',
      delete: 'Delete',
      confirm: 'Confirm',
      cancel: 'Cancel',
      send: 'Send',
      connectionName: 'Connection name',
      client: 'Client',
      hostName: 'Host name',
      port: 'Port',
      user: 'User',
      password: 'Password',
      credentials: 'Credentials',
      connect: 'Connect',
      connected: 'Connected',
      disconnect: 'Disconnect',
      disconnected: 'Disconnected',
      refresh: 'Refresh',
      settings: 'Settings',
      general: 'General',
      themes: 'Themes',
      update: 'Update',
      about: 'About',
      language: 'Language',
      version: 'Version',
      donate: 'Donate',
      run: 'Run',
      schema: 'Schema',
      results: 'Results',
      size: 'Size',
      seconds: 'Seconds',
      type: 'Type',
      mimeType: 'Mime-Type',
      download: 'Download',
      add: 'Add',
      data: 'Data',
      properties: 'Properties',
      insert: 'Insert',
      connecting: 'Connecting',
      name: 'Name',
      collation: 'Collation'
   },
   message: {
      appWelcome: 'Welcome to Antares SQL Client!',
      appFirstStep: 'Your first step: create a new database connection.',
      addConnection: 'Add connection',
      createConnection: 'Create connection',
      createNewConnection: 'Create new connection',
      askCredentials: 'Ask for credentials',
      testConnection: 'Test connection',
      editConnection: 'Edit connection',
      deleteConnection: 'Delete connection',
      deleteCorfirm: 'Do you confirm the cancellation of',
      connectionSuccessfullyMade: 'Connection successfully made!',
      madeWithJS: 'Made with 💛 and JavaScript!',
      checkForUpdates: 'Check for updates',
      noUpdatesAvailable: 'No updates available',
      checkingForUpdate: 'Checking for updates',
      checkFailure: 'Check failed, please try later',
      updateAvailable: 'Update available',
      downloadingUpdate: 'Downloading update',
      updateDownloaded: 'Update downloaded',
      restartToInstall: 'Restart Antares to install',
      unableEditFieldWithoutPrimary: 'Unable to edit a field without a primary key in resultset',
      editCell: 'Edit cell',
      deleteRows: 'Delete row | Delete {count} rows',
      confirmToDeleteRows: 'Do you confirm to delete one row? | Do you confirm to delete {count} rows?',
      notificationsTimeout: 'Notifications timeout',
      uploadFile: 'Upload file',
      addNewRow: 'Add new row',
      numberOfInserts: 'Number of inserts',
      openNewTab: 'Open a new tab',
      affectedRows: 'Affected rows',
      createNewDatabase: 'Create new Database',
      databaseName: 'Database name',
      serverDefault: 'Server default',
      deleteDatabase: 'Delete database',
      editDatabase: 'Edit database'
   },
   // Date and Time
   short: {
      year: 'numeric',
      month: 'short',
      day: 'numeric'
   },
   long: {
      year: 'numeric',
      month: 'short',
      day: 'numeric',
      weekday: 'short',
      hour: 'numeric',
      minute: 'numeric'
   }
};

==> v0.0.8.zip: antares/src/renderer/i18n/en-US.js <==
module.exports = {
   word: {
      edit: 'Edit',
      save: 'Save',
      close: 'Close',
      delete: 'Delete',
      confirm: 'Confirm',
      cancel: 'Cancel',
      send: 'Send',
      connectionName: 'Connection name',
      client: 'Client',
      hostName: 'Host name',
      port: 'Port',
      user: 'User',
      password: 'Password',
      credentials: 'Credentials',
      connect: 'Connect',
      connected: 'Connected',
      disconnect: 'Disconnect',
      disconnected: 'Disconnected',
      refresh: 'Refresh',
      settings: 'Settings',
      general: 'General',
      themes: 'Themes',
      update: 'Update',
      about: 'About',
      language: 'Language',
      version: 'Version',
      donate: 'Donate',
      run: 'Run',
      schema: 'Schema',
      results: 'Results',
      size: 'Size',
      seconds: 'Seconds',
      type: 'Type',
      mimeType: 'Mime-Type',
      download: 'Download',
      add: 'Add',
      data: 'Data',
      properties: 'Properties',
      insert: 'Insert',
      connecting: 'Connecting',
      name: 'Name',
      collation: 'Collation',
      autoRefresh: 'Auto-refresh'
   },
   message: {
      appWelcome: 'Welcome to Antares SQL Client!',
      appFirstStep: 'Your first step: create a new database connection.',
      addConnection: 'Add connection',
      createConnection: 'Create connection',
      createNewConnection: 'Create new connection',
      askCredentials: 'Ask for credentials',
      testConnection: 'Test connection',
      editConnection: 'Edit connection',
      deleteConnection: 'Delete connection',
      deleteCorfirm: 'Do you confirm the cancellation of',
      connectionSuccessfullyMade: 'Connection successfully made!',
      madeWithJS: 'Made with 💛 and JavaScript!',
      checkForUpdates: 'Check for updates',
      noUpdatesAvailable: 'No updates available',
      checkingForUpdate: 'Checking for updates',
      checkFailure: 'Check failed, please try later',
      updateAvailable: 'Update available',
      downloadingUpdate: 'Downloading update',
      updateDownloaded: 'Update downloaded',
      restartToInstall: 'Restart Antares to install',
      unableEditFieldWithoutPrimary: 'Unable to edit a field without a primary key in resultset',
      editCell: 'Edit cell',
      deleteRows: 'Delete row | Delete {count} rows',
      confirmToDeleteRows: 'Do you confirm to delete one row? | Do you confirm to delete {count} rows?',
      notificationsTimeout: 'Notifications timeout',
      uploadFile: 'Upload file',
      addNewRow: 'Add new row',
      numberOfInserts: 'Number of inserts',
      openNewTab: 'Open a new tab',
      affectedRows: 'Affected rows',
      createNewDatabase: 'Create new Database',
      databaseName: 'Database name',
      serverDefault: 'Server default',
      deleteDatabase: 'Delete database',
      editDatabase: 'Edit database'
   },
   // Date and Time
   short: {
      year: 'numeric',
      month: 'short',
      day: 'numeric'
   },
   long: {
      year: 'numeric',
      month: 'short',
      day: 'numeric',
      weekday: 'short',
      hour: 'numeric',
      minute: 'numeric'
   }
};
